@@ -18,7 +18,7 @@ use File::Find;
 use Storable "fd_retrieve", "store_fd";
 use Sys::Hostname;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 # comma separated list of default plugins
 my $DEFAULT_PLUGINS = join ",", qw(DPath
@@ -293,8 +293,9 @@ sub run_plugin
 # Benchmark::Perl::Formance and should be replaced
 # with something generic
 sub _perl_gitversion {
-        my $perlpath         = "$^X";
-        my $perl_gitversion  = "$perlpath-gitversion";
+        my $perlpath = "$^X";
+        $perlpath    =~ s,/[^/]*$,,;
+        my $perl_gitversion  = "$perlpath/perl-gitversion";
 
         if (-x $perl_gitversion) {
                 my $gitversion = qx!$perl_gitversion! ;
@@ -303,6 +304,18 @@ sub _perl_gitversion {
         }
 }
 
+sub _perl_codespeed_executable {
+        my $perlpath = "$^X";
+        $perlpath    =~ s,/[^/]*$,,;
+        my $perl_codespeed_executable  = "$perlpath/perl-codespeed-executable";
+
+        if (-x $perl_codespeed_executable) {
+                my $executable = qx!$perl_codespeed_executable! ;
+                chomp $executable;
+                return $executable;
+        }
+}
+
 sub _get_hostname {
         my $host = "unknown-hostname";
         eval { $host = hostname };
@@ -320,12 +333,11 @@ sub generate_codespeed_data
         my $len = max map { length } @run_plugins;
 
         my $codespeed_exe_suffix  = $self->{options}{cs_executable_suffix}  || $ENV{CODESPEED_EXE_SUFFIX}  || "";
-        my $codespeed_exe         = $self->{options}{cs_executable}         || sprintf("perl-%s.%s.%s%s",
-                                                                                       $Config{PERL_REVISION},
-                                                                                       $Config{PERL_VERSION},
-                                                                                       $Config{PERL_SUBVERSION},
-                                                                                       $codespeed_exe_suffix,
-                                                                                      );
+        my $codespeed_exe         = $self->{options}{cs_executable}         || _perl_codespeed_executable  || sprintf("perl-%s.%s%s",
+                                                                                                                      $Config{PERL_REVISION},
+                                                                                                                      $Config{PERL_VERSION},
+                                                                                                                      $codespeed_exe_suffix,
+                                                                                                                     );
         my $codespeed_project     = $self->{options}{cs_project}            || $ENV{CODESPEED_PROJECT}     || "perl";
         my $codespeed_branch      = $self->{options}{cs_branch}             || $ENV{CODESPEED_BRANCH}      || "default";
         my $codespeed_commitid    = $self->{options}{cs_commitid}           || $ENV{CODESPEED_COMMITID}    || $Config{git_commit_id} || _perl_gitversion || "no-commit";
@@ -552,7 +564,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance - Perl Performance Benchmark Suite
+Benchmark::Perl::Formance - PerlFormance - Benchmark Suite
 
 =head1 ABOUT
 
